export type Serializer<From, To extends From = From> = {
    description: string;
    fixedSize: number | null;
    serialize: (value: From) => Uint8Array;
    deserialize: (buffer: Uint8Array, offset?: number) => [To, number];
};
export type NumberSerializer = Serializer<number> | Serializer<number | bigint, bigint>;
export type WrapInSerializer<T, U extends T = T> = {
    [P in keyof T]: Serializer<T[P], U[P]>;
};
export declare function mapSerializer<NewFrom, OldFrom, To extends NewFrom & OldFrom>(serializer: Serializer<OldFrom, To>, unmap: (value: NewFrom) => OldFrom): Serializer<NewFrom, To>;
export declare function mapSerializer<NewFrom, OldFrom, NewTo extends NewFrom = NewFrom, OldTo extends OldFrom = OldFrom>(serializer: Serializer<OldFrom, OldTo>, unmap: (value: NewFrom) => OldFrom, map: (value: OldTo, buffer: Uint8Array, offset: number) => NewTo): Serializer<NewFrom, NewTo>;
export declare const swapEndianness: (buffer: Uint8Array, bytes?: number) => Uint8Array;
export declare const sumSerializerFixedSizes: (serializers: {
    fixedSize: number | null;
}[]) => number | null;
